@@ -988,15 +988,15 @@ free_ant(Display *display, antfarmstruct *ap)
 	}
 	ap->init_bits = 0;
 	if (ap->tape != NULL) {
-		(void) free((void *) ap->tape);
+		free(ap->tape);
 		ap->tape = (unsigned char *) NULL;
 	}
 	if (ap->ants != NULL) {
-		(void) free((void *) ap->ants);
+		free(ap->ants);
 		ap->ants = (antstruct *) NULL;
 	}
 	if (ap->truchet_state != NULL) {
-		(void) free((void *) ap->truchet_state);
+		free(ap->truchet_state);
 		ap->truchet_state = (unsigned char *) NULL;
 	}
 }
@@ -1041,7 +1041,7 @@ init_ant(ModeInfo * mi)
 	if (ap->n < -MINANTS) {
 		/* if ap->n is random ... the size can change */
 		if (ap->ants != NULL) {
-			(void) free((void *) ap->ants);
+			free(ap->ants);
 			ap->ants = (antstruct *) NULL;
 		}
 		ap->n = NRAND(-ap->n - MINANTS + 1) + MINANTS;
@@ -1190,14 +1190,14 @@ init_ant(ModeInfo * mi)
 		}
 	}
 	if (ap->tape != NULL) 
-		(void) free((void *) ap->tape);
+		free(ap->tape);
 	if ((ap->tape = (unsigned char *) calloc(ap->ncols * ap->nrows,
 			sizeof (unsigned char))) == NULL) {
 		free_ant(display, ap);
 		return;
 	}
 	if (ap->truchet_state != NULL)
-		(void) free((void *) ap->truchet_state);
+		free(ap->truchet_state);
 	if ((ap->truchet_state = (unsigned char *) calloc(ap->ncols * ap->nrows,
 			sizeof (unsigned char))) == NULL) {
 		free_ant(display, ap);
@@ -1329,7 +1329,7 @@ release_ant(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_ant(MI_DISPLAY(mi), &antfarms[screen]);
-		(void) free((void *) antfarms);
+		free(antfarms);
 		antfarms = (antfarmstruct *) NULL;
 	}
 }
