@@ -755,7 +755,7 @@ flush_buglist(bugfarmstruct * bp)
 		bp->currbug->previous->next = bp->lastbug;
 		bp->lastbug->previous = bp->currbug->previous;
 		/*bp->arr[bp->currbug->info.col + bp->currbug->info.row * bp->ncols] = 0; */
-		(void) free((void *) bp->currbug);
+		free(bp->currbug);
 	}
 
 	while (bp->lasttemp->previous != bp->firsttemp) {
@@ -763,7 +763,7 @@ flush_buglist(bugfarmstruct * bp)
 		bp->currbug->previous->next = bp->lasttemp;
 		bp->lasttemp->previous = bp->currbug->previous;
 		/*bp->arr[bp->currbug->info.col + bp->currbug->info.row * bp->ncols] = 0; */
-		(void) free((void *) bp->currbug);
+		free(bp->currbug);
 	}
 }
 
@@ -772,19 +772,19 @@ free_buglist(bugfarmstruct *bp)
 {
 	if (bp->firstbug != NULL) {
 		flush_buglist(bp);
-		(void) free((void *) bp->firstbug);
+		free(bp->firstbug);
 		bp->firstbug = (BugList *) NULL;
 	}
 	if (bp->lastbug != NULL) {
-		(void) free((void *) bp->lastbug);
+		free(bp->lastbug);
 		bp->lastbug = (BugList *) NULL;
 	}
 	if (bp->lasttemp != NULL) {
-		(void) free((void *) bp->lasttemp);
+		free(bp->lasttemp);
 		bp->lasttemp = (BugList *) NULL;
 	}
 	if (bp->firsttemp != NULL) {
-		(void) free((void *) bp->firsttemp);
+		free(bp->firsttemp);
 		bp->firsttemp = (BugList *) NULL;
 	}
 }
@@ -842,7 +842,7 @@ removefrom_buglist(bugfarmstruct * bp, BugList * ptr)
 	ptr->previous->next = ptr->next;
 	ptr->next->previous = ptr->previous;
 	bp->arr[ptr->info.col + ptr->info.row * bp->ncols] = 0;
-	(void) free((void *) ptr);
+	free(ptr);
 }
 
 static void
@@ -1018,27 +1018,27 @@ free_bug(Display *display, bugfarmstruct *bp)
 	bp->init_bits = 0;
 	if (bp->firstbug != NULL) {
 		flush_buglist(bp);
-		(void) free((void *) bp->firstbug);
+		free(bp->firstbug);
 		bp->firstbug = (BugList *) NULL;
 	}
 	if (bp->lastbug != NULL) {
-		(void) free((void *) bp->lastbug);
+		free(bp->lastbug);
 		bp->lastbug = (BugList *) NULL;
 	}
 	if (bp->lasttemp != NULL) {
-		(void) free((void *) bp->lasttemp);
+		free(bp->lasttemp);
 		bp->lasttemp = (BugList *) NULL;
 	}
 	if (bp->firsttemp != NULL) {
-		(void) free((void *) bp->firsttemp);
+		free(bp->firsttemp);
 		bp->firsttemp = (BugList *) NULL;
 	}
 	if (bp->arr != NULL) {
-		(void) free((void *) bp->arr);
+		free(bp->arr);
 		bp->arr = (BugList **) NULL;
 	}
 	if (bp->bacteria != NULL) {
-		(void) free((void *) bp->bacteria);
+		free(bp->bacteria);
 		bp->bacteria = (char *) NULL;
 	}
 }
@@ -1142,14 +1142,14 @@ init_bug(ModeInfo * mi)
 	bp->xb = (bp->width - bp->xs * nccols) / 2;
 	bp->yb = (bp->height - bp->ys * ncrows) / 2;
 	if (bp->arr != NULL)
-		(void) free((void *) bp->arr);
+		free(bp->arr);
 	if ((bp->arr = (BugList **) calloc(bp->ncols * bp->nrows,
 			sizeof (BugList *))) == NULL) {
 		free_bug(display, bp);
 		return;
 	}
 	if (bp->bacteria != NULL)
-		(void) free((void *) bp->bacteria);
+		free(bp->bacteria);
 	if ((bp->bacteria = (char *) calloc(bp->ncols * bp->nrows,
 			sizeof (char))) == NULL) {
 		free_bug(display, bp);
@@ -1406,7 +1406,7 @@ release_bug(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_bug(MI_DISPLAY(mi), &bugfarms[screen]);
-		(void) free((void *) bugfarms);
+		free(bugfarms);
 		bugfarms = (bugfarmstruct *) NULL;
 	}
 }
