@@ -2,7 +2,7 @@
 /* crystal --- polygons moving according to plane group rules */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)crystal.c	5.00 2000/11/01 xlockmore";
+static const char sccsid[] = "@(#)crystal.c	5.08 2003/04/28 xlockmore";
 
 #endif
 
@@ -32,7 +32,16 @@ static const char sccsid[] = "@(#)crystal.c	5.00 2000/11/01 xlockmore";
  *   square groups 3 through 11 where the angle gamma is 90 degrees
  *   hexagonal groups 12 through 17 where the angle gamma is 120 degrees
  *
+ * TODO:
+ *   Crystals (particularly the parallelagram ones) favor the lower
+ *     right corner in small windows.
+ *   Parallelagrams always look like this:
+ *      __      __                   /|
+ *     /_/  or  \_\  but never like  |/  (coded this way because screen is
+ *     usually longer horizontally).
+ *
  * Revision History:
+ * 28-Apr-2003: Changed so it works in a 64x64 window
  * 01-Nov-2000: Allocation checks
  * 03-Dec-1998: Random inversion of y-axis included to simulate hexagonal
  *              groups with an angle of 60 degrees.
@@ -740,7 +749,7 @@ init_crystal(ModeInfo * mi)
 			return;
 		}
 
-	if (maxsize) {
+	if (maxsize || MI_WIDTH(mi) < 92 || MI_HEIGHT(mi) < 92) {
 		if (cryst->planegroup < 13) {
 			cryst->gamma = 90.0;
 			cryst->offset_w = 0;
