@@ -457,14 +457,14 @@ convert(double x, char *string)
 static void
 dayhrminsec(long timeCount, int tzoffset, char *string)
 {
-	int days, hours, minutes, seconds;
+	int days, hours, minutes, secs;
 	int bufsize, i;
 
 	timeCount = ABS(timeCount);
 	days = (int) (timeCount / 86400);
 	hours = (int) ((timeCount / 3600) % 24);
 	minutes = (int) ((timeCount / 60) % 60);
-	seconds = (int) (timeCount % 60);
+	secs = (int) (timeCount % 60);
 
 	/* snprintf would make this easier but its not always available */
 	bufsize = 16 + strlen((days==1) ? DAY : DAYS);
@@ -485,10 +485,10 @@ dayhrminsec(long timeCount, int tzoffset, char *string)
 	(void) sprintf(&string[i], " %d %s", minutes, (minutes==1) ? MINUTE : MINUTES);
 
 	i = strlen(string);
-	bufsize += 4 + strlen((seconds==1) ? SECOND : SECONDS);
+	bufsize += 4 + strlen((secs==1) ? SECOND : SECONDS);
 	if (i + bufsize >= STRSIZE)
           return;
-	(void) sprintf(&string[i], " %d %s", seconds, (seconds==1) ? SECOND : SECONDS);
+	(void) sprintf(&string[i], " %d %s", secs, (secs==1) ? SECOND : SECONDS);
 
 	if (!tzoffset) {
 		i = strlen(string);
@@ -500,7 +500,7 @@ dayhrminsec(long timeCount, int tzoffset, char *string)
 }
 
 static void
-drawaled(ModeInfo * mi, int startx, int starty, int led)
+drawaled(ModeInfo * mi, int startx, int starty, int aled)
 {
 	Display    *display = MI_DISPLAY(mi);
 	dclockstruct *dp = &dclocks[MI_SCREEN(mi)];
@@ -510,7 +510,7 @@ drawaled(ModeInfo * mi, int startx, int starty, int led)
 	int offset2 = (int) (LED_WIDTH / 2.0);
 	int leanoffset = (int) (offset2 * LED_LEAN);
 
-	switch (led) {
+	switch (aled) {
 		case 0: /* a */
 			x_1 = startx + dp->parallelogram[0].x;
 			y_1 = starty + dp->parallelogram[0].y;
@@ -610,11 +610,11 @@ drawacolon(ModeInfo * mi, int startx, int starty)
 static void
 drawanumber(ModeInfo * mi, int startx, int starty, int digit)
 {
-	int led;
+	int aled;
 
-	for (led = 0; led < MAX_LEDS; led++) {
-		if (digits[digit][led])
-			drawaled(mi, startx, starty, led);
+	for (aled = 0; aled < MAX_LEDS; aled++) {
+		if (digits[digit][aled])
+			drawaled(mi, startx, starty, aled);
 	}
 }
 
