@@ -932,15 +932,15 @@ free_fire(firestruct *fs)
 	}
 
 	if (fs->p != NULL) {
-		(void) free((void *) fs->p);
+		free(fs->p);
 		fs->p = (part *) NULL;
 	}
 	if (fs->r != NULL) {
-		(void) free((void *) fs->r);
+		free(fs->r);
 		fs->r = (rain *) NULL;
 	}
 	if (fs->treepos != NULL) {
-		(void) free((void *) fs->treepos);
+		free(fs->treepos);
 		fs->treepos = (treestruct *) NULL;
 	}
 	if (fs->ttexture != None) {
@@ -1064,7 +1064,7 @@ void release_fire(ModeInfo * mi)
     int screen;
 	for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 		free_fire(&fire[screen]);
-	(void) free((void *) fire);
+	free(fire);
 	fire = (firestruct *) NULL;
     }
     if (mode_font != None)
