@@ -1226,7 +1226,7 @@ release_gears(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_gears(MI_DISPLAY(mi), &gears[screen]);
-		(void) free((void *) gears);
+		free(gears);
 		gears = (gearsstruct *) NULL;
 	}
 	FreeAllGL(mi);
