@@ -361,7 +361,7 @@ free_fonts (ModeInfo *mi)
   clear_gl_error ();
   if (glIsList(mc->molecule_dlist)) {
 	glDeleteLists(mc->molecule_dlist, 1);
-	check_gl_error ("glDeleteLists");
+	(void) check_gl_error ("glDeleteLists");
 	mc->molecule_dlist = 0;
   }
   if (mc->xfont1) {
@@ -371,7 +371,7 @@ free_fonts (ModeInfo *mi)
 	clear_gl_error ();
 	if (glIsList(mc->font1_dlist)) {
 		glDeleteLists (mc->font1_dlist,(GLuint) last+1);
-		check_gl_error ("glDeleteLists");
+		(void) check_gl_error ("glDeleteLists");
 		mc->font1_dlist = 0;
 	}
 	XFreeFont(MI_DISPLAY(mi),mc->xfont1);
@@ -384,7 +384,7 @@ free_fonts (ModeInfo *mi)
 	clear_gl_error ();
 	if (glIsList(mc->font2_dlist)) {
 		glDeleteLists (mc->font2_dlist,(GLuint) last+1);
-		check_gl_error ("glDeleteLists");
+		(void) check_gl_error ("glDeleteLists");
 		mc->font2_dlist = 0;
 	}
 	XFreeFont(MI_DISPLAY(mi),mc->xfont2);
