@@ -1990,7 +1990,9 @@ draw_rubik(ModeInfo * mi)
 		release_rubik(mi);
 		return;
 	}
-        if (MI_IS_FPS(mi)) do_fps (mi);
+        if (MI_IS_FPS(mi)) {
+		do_fps (mi);
+	}
 	glXSwapBuffers(display, window);
 
 	if (rp->action == ACTION_SHUFFLE) {
