@@ -812,7 +812,7 @@ void release_sballs(ModeInfo * mi)
 		XDestroyImage(sb->ftexture);
 	    }
 	}
-	(void) free((void *) sballs);
+	free(sballs);
 	sballs = (sballsstruct *) NULL;
     }
     FreeAllGL(mi);
