@@ -31,7 +31,7 @@ static const char sccsid[] = "@(#)xpm-image.c       5.0 00/11/14 xlockmore";
 
 #include <X11/Intrinsic.h>
 
-#if HAVE_XPM
+#ifdef HAVE_XPM
 #include <X11/xpm.h>
 
 #include <X11/Xutil.h>
