@@ -377,17 +377,17 @@ free_goop(Display * display, goopstruct * gp)
 
 				for (b = 0; b < gp->layers[l].nblobs; b++) {
 					if (gp->layers[l].blobs[b].r != NULL)
-						(void) free((void *) gp->layers[l].blobs[b].r);
+						free(gp->layers[l].blobs[b].r);
 					free_spline(gp->layers[l].blobs[b].splines);
 				}
-				(void) free((void *) gp->layers[l].blobs);
+				free(gp->layers[l].blobs);
 			}
 			if (gp->layers[l].gc != None)
 				XFreeGC(display, gp->layers[l].gc);
 			if (gp->layers[l].pixmap != None)
 				XFreePixmap(display, gp->layers[l].pixmap);
 		}
-		(void) free((void *) gp->layers);
+		free(gp->layers);
 		gp->layers = (layer *) NULL;
 	}
 	if (gp->pixmap_gc != None) {
@@ -479,7 +479,7 @@ init_goop(ModeInfo * mi)
 			if (!make_layer(mi, &(gp->layers[i]),
 				   (nblobs > 0 ? nblobs : lblobs[i])))
 				free_goop(display, gp);
-		(void) free((void *) lblobs);
+		free(lblobs);
 	}
 
 	if (gp->mode == transparent && plane_masks) {
@@ -488,7 +488,7 @@ init_goop(ModeInfo * mi)
 		gp->background = base_pixel;
 	}
 	if (plane_masks)
-		(void) free((void *) plane_masks);
+		free(plane_masks);
 
 	if (gp->mode != transparent) {
 		gp->background = 0;	/* init */
@@ -610,7 +610,7 @@ release_goop(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_goop(MI_DISPLAY(mi), &goops[screen]);
-		(void) free((void *) goops);
+		free(goops);
 		goops = (goopstruct *) NULL;
 	}
 }
