@@ -765,12 +765,12 @@ projectile(jugglestruct *sp)
 	if (t->action == THROW) {
 	  if (t->balllink != NULL) {
 		if (t->posn == '_') { /* Bounce once */
-		  double tc, y0, yf, yc, tb, e, i;
+		  double tc, yo, yf, yc, tb, e, i;
 
 		  tc = t->balllink->start - t->start;
 
 		  yf = sp->cy + FY;
-		  y0 = t->y;
+		  yo = t->y;
 		  yc = t->balllink->y;
 		  e = 1; /* permissible error in yc */
 
@@ -787,7 +787,7 @@ projectile(jugglestruct *sp)
 			  (void) fprintf(stderr, "div by zero!\n");
 			  break;
 			}
-			dy = (yf - y0)/tb + 0.5*sp->Gr*tb;
+			dy = (yf - yo)/tb + 0.5*sp->Gr*tb;
 			dt = tc - tb;
 			yt = -COR*dy*dt + 0.5*sp->Gr*dt*dt + yf;
 			if(yt > yc + e){
@@ -815,7 +815,7 @@ projectile(jugglestruct *sp)
 			n->divisions = t->divisions;
 			n->status = PREDICTOR;
 
-			t->dy = (yf - y0)/tb - 0.5*sp->Gr*tb;
+			t->dy = (yf - yo)/tb - 0.5*sp->Gr*tb;
 			t0 = n->start;
 			/* Represent parabola as a degenerate spline -
 			   linear in x, quadratic in y */
@@ -845,7 +845,7 @@ projectile(jugglestruct *sp)
 			n->xp.c = t->dx;
 			n->xp.d = -t->dx*t0 + t->x;
 
-			dy = (yf - y0)/tb + 0.5*sp->Gr*tb;
+			dy = (yf - yo)/tb + 0.5*sp->Gr*tb;
 			t0 = n->start;
 			/* Represent parabola as a degenerate spline -
 			   linear in x, quadratic in y */
@@ -1131,7 +1131,6 @@ init_juggle(ModeInfo * mi)
 	}
 	if (pattern == NULL && patternindex == NULL) {
 	  /* pattern list needs indexing */
-	  int i;
 	  int nelements = sizeof(portfolio)/sizeof(patternstruct);
 	  int maxballs;
 	  int numpat = 0;
