@@ -319,31 +319,31 @@ free_kumppa(Display *display, kumppastruct *s)
 		}
 	}
 	if (s->acosinus != NULL) {
-		(void) free((void *) s->acosinus);
+		free(s->acosinus);
 		s->acosinus = (float *) NULL;
 	}
 	if (s->Xrotations != NULL) {
-		(void) free((void *) s->Xrotations);
+		free(s->Xrotations);
 		s->Xrotations = (int *) NULL;
 	}
 	if (s->Yrotations != NULL) {
-		(void) free((void *) s->Yrotations);
+		free(s->Yrotations);
 		s->Yrotations = (int *) NULL;
 	}
 	if (s->Xrottable != NULL) {
-		(void) free((void *) s->Xrottable);
+		free(s->Xrottable);
 		s->Xrottable = (int *) NULL;
 	}
 	if (s->Yrottable != NULL) {
-		(void) free((void *) s->Yrottable);
+		free(s->Yrottable);
 		s->Yrottable = (int *) NULL;
 	}
 	if (s->rotateX != NULL) {
-		(void) free((void *) s->rotateX);
+		free(s->rotateX);
 		s->rotateX = (int *) NULL;
 	}
 	if (s->rotateY != NULL) {
-		(void) free((void *) s->rotateY);
+		free(s->rotateY);
 		s->rotateY = (int *) NULL;
 	}
 }
@@ -365,13 +365,13 @@ make_rots(ModeInfo * mi, double xspeed, double yspeed)
 	iy = (double) (s->midy + 1) / (double) (s->rotsizeY);
 
 	if (s->Xrotations != NULL)
-		(void) free((void *) s->Xrotations);
+		free(s->Xrotations);
 	if (s->Yrotations != NULL)
-		(void) free((void *) s->Yrotations);
+		free(s->Yrotations);
 	if (s->Xrottable != NULL)
-		(void) free((void *) s->Xrottable);
+		free(s->Xrottable);
 	if (s->Yrottable != NULL)
-		(void) free((void *) s->Yrottable);
+		free(s->Yrottable);
 
 	if (((s->Xrotations = (int *) calloc((s->midx + 2),
 			sizeof (int))) == NULL) ||
@@ -445,11 +445,11 @@ make_rots(ModeInfo * mi, double xspeed, double yspeed)
 	}
 	s->Xrottable[a] = c;
 	if (s->rotateX)
-		(void) free((void *) s->rotateX);
+		free(s->rotateX);
 	if ((s->rotateX = (int *) calloc((maxi + 2) << 1,
 			sizeof (int))) == NULL) {
 		free_kumppa(MI_DISPLAY(mi), s);
-		(void) free((void *) chks);
+		free(chks);
 		return; 
 	}
 
@@ -511,15 +511,15 @@ make_rots(ModeInfo * mi, double xspeed, double yspeed)
 	}
 	s->Yrottable[a] = c;
 	if (s->rotateY)
-		(void) free((void *) s->rotateY);
+		free(s->rotateY);
 	if ((s->rotateY = (int *) calloc((maxi + 2) << 1,
 			sizeof (int))) == NULL) {
 		free_kumppa(MI_DISPLAY(mi), s);
-		/* (void) free((void *) chks); */
+		/* free(chks); */
 		/* return; */
 	}
 
-	(void) free((void *) chks);
+	free(chks);
 }
 
 #ifndef STANDALONE
@@ -806,7 +806,7 @@ release_kumppa(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_kumppa(MI_DISPLAY(mi), &kumppas[screen]);
-		(void) free((void *) kumppas);
+		free(kumppas);
 		kumppas = (kumppastruct *) NULL;
 	}
 }
