@@ -305,7 +305,7 @@ typedef struct {
 	int         graphics_format;
 	GC          backGC;
 	int neighbors;
-	int highlife, daynight, callahan, andreen, trilife;
+	int highlife, daynight, callahan, andreen, trilife, trilife1, trilife2;
 	int allPatterns, allGliders;
 	paramstruct input_param;
 
@@ -771,6 +771,26 @@ parseRule(ModeInfo * mi)
 			lp->input_param.birth_group[n] = param_12rules[0].birth_group[n];
 		}
 		return;
+	} else if (lp->trilife1) {
+		lp->neighbors = 12;
+		neighbor_kind = invplot(lp->neighbors);
+		found = !MI_IS_FULLRANDOM(mi);
+		lp->input_param.survival = param_12rules[1].survival;
+		lp->input_param.birth = param_12rules[1].birth;
+		for (n = 0; n < maxgroups[neighbor_kind]; n++) {
+			lp->input_param.survival_group[n] = param_12rules[1].survival_group[n];
+			lp->input_param.birth_group[n] = param_12rules[1].birth_group[n];
+		}
+	} else if (lp->trilife2) {
+		lp->neighbors = 12;
+		neighbor_kind = invplot(lp->neighbors);
+		found = !MI_IS_FULLRANDOM(mi);
+		lp->input_param.survival = param_12rules[2].survival;
+		lp->input_param.birth = param_12rules[2].birth;
+		for (n = 0; n < maxgroups[neighbor_kind]; n++) {
+			lp->input_param.survival_group[n] = param_12rules[2].survival_group[n];
+			lp->input_param.birth_group[n] = param_12rules[2].birth_group[n];
+		}
 	}
 	neighbor_kind = invplot(lp->neighbors);
 	if (rule && !MI_IS_FULLRANDOM(mi)) {
@@ -837,14 +857,16 @@ parseFile(ModeInfo *mi)
 	FILE       *file;
 	static Bool done = False;
 	int         firstx, x = 0, y = 0, i = 0;
-	int         c;
+	int         c, size;
 	char        line[256];
 
 	if (done)
 		return;
 	done = True;
-	if (MI_IS_FULLRANDOM(mi) || !lifefile || !*lifefile || ((file = my_fopen(lifefile, "r")) == NULL)) {
-		/*(void) fprintf(stderr, "could not read file \"%s\"\n", lifefile); */
+	if (MI_IS_FULLRANDOM(mi) || !lifefile || !*lifefile)
+		return;
+	if ((file = my_fopenSize(lifefile, "r", &size)) == NULL) {
+		(void) fprintf(stderr, "could not read file \"%s\"\n", lifefile);
 		return;
 	}
 	for (;;) {
@@ -869,14 +891,14 @@ parseFile(ModeInfo *mi)
 		return;
 	}
 	firstx = x;
-	if ((filePattern = (char *) malloc((2 * NUMFILEPTS + 1) *
+	if ((filePattern = (char *) malloc((2 * size) *
 			sizeof (char))) == NULL) {
 		(void) fprintf(stderr, "not enough memory\n");
 		(void) fclose(file);
 		return;
 	}
 
-	while (c != EOF && x < 127 && y < 127 && i < 2 * NUMFILEPTS) {
+	while (c != EOF && x < 127 && y < 127 && i < 2 * size) {
 		if (c == '0' || c == 'O' || c == '*') {
 			filePattern[i++] = x++;
 			filePattern[i++] = y;
@@ -1352,11 +1374,15 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 				break;
 		}
 	}
+#ifdef DEBUG
+	orient = 0;
+#else
 	if (lp->neighbors == 4 || lp->neighbors == 8) {
 		orient = NRAND(8);
 	} else {
 		orient = NRAND(12);
 	}
+#endif
 	while ((col = *patptr++) != 127) {
 		row = *patptr++;
 		if (lp->neighbors == 6) {
@@ -1955,8 +1981,11 @@ init_life(ModeInfo * mi)
 		int r6n1 = patterns_6rules[0] + patterns_6rules[1];
 		int r8n1 = patterns_8rules[0] + patterns_8rules[1];
 		int r8n2 = r8n1 + patterns_8rules[2];
+		int r12n1 = patterns_12rules[0] + patterns_12rules[1];
+		int r12n2 = r12n1 + patterns_12rules[2];
 #if 1
-		lp->neighbors = (NRAND(r8n2 + r6n1 / 2) < r8n2) ? 8 : 6;
+		lp->neighbors = (NRAND(r8n2 + r6n1 + r12n2) < r8n2) ? 8 :
+			(NRAND(r6n1 + r12n2) < r6n1) ? 6 : 12;
 #else
 		lp->neighbors = 8;
 #endif
@@ -1974,13 +2003,23 @@ init_life(ModeInfo * mi)
 		} else {
 	   		lp->andreen = lp->callahan = False;
 		}
-		lp->trilife = (lp->neighbors != 12);
+		if  (lp->neighbors == 12) {
+			int n = NRAND(r12n2);
+
+			lp->trilife = (n < r12n1);
+			lp->trilife1 = (n >= r12n1 && n < r12n2);
+			lp->trilife2 = (n >= r12n2);
+		} else {
+	   		lp->trilife = lp->trilife1 = lp->trilife2 = False;
+		}
 	} else {
 	   	lp->highlife = highlife;
 	   	lp->daynight = daynight;
 	   	lp->callahan = callahan;
 	   	lp->andreen = andreen;
 	   	lp->trilife = trilife;
+	   	lp->trilife1 = False;
+	   	lp->trilife2 = False;
 	}
 	if (!lp->neighbors) {
 		for (i = 0; i < NEIGHBORKINDS; i++) {
