@@ -22,6 +22,7 @@ static const char sccsid[] = "@(#)life3d.c	5.07 2003/01/08 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
+ * 28-Apr-2003: Randomized "rotation" of life form
  * 25-Jan-2003: Spawned a life3d.h
  * 19-Jan-2003: added more gliders from http://www.cse.sc.edu/~bays
  * 08-Jan-2003: Double buffering
@@ -288,20 +289,21 @@ parseRule(ModeInfo * mi)
 }
 
 static void
-parseFile(void)
+parseFile(ModeInfo *mi)
 {
 	FILE       *file;
 	static Bool done = False;
 	int         firstx, firsty, x = 0, y = 0, z = 0, i = 0;
-	int         c, cprev = ' ';
+	int         c, cprev = ' ', size;
 	char        line[256];
 
 	if (done)
 		return;
 	done = True;
-	if (!lifefile || !*lifefile ||
-	    ((file = my_fopen(lifefile, "r")) == NULL)) {
-		/*(void) fprintf(stderr, "could not read file \"%s\"\n", lifefile); */
+	if (MI_IS_FULLRANDOM(mi) || !lifefile || !*lifefile)
+		return;
+	if ((file = my_fopenSize(lifefile, "r", &size)) == NULL) {
+		(void) fprintf(stderr, "could not read file \"%s\"\n", lifefile);
 		return;
 	}
 	for (;;) {
@@ -328,13 +330,13 @@ parseFile(void)
 	}
 	firstx = x;
 	firsty = y;
-	if ((filePattern = (char *) malloc((3 * NUMFILEPTS + 1) *
+	if ((filePattern = (char *) malloc((3 * size) *
 			 sizeof (char))) == NULL) {
 		(void) fprintf(stderr, "not enough memory\n");
 		(void) fclose(file);
 	}
 
-	while (c != EOF && x < 127 && y < 127 && i < 3 * NUMFILEPTS) {
+	while (c != EOF && x < 127 && y < 127 && i < 3 * size) {
 		if (c == '0' || c == 'O' || c == '*') {
 			filePattern[i++] = x++;
 			filePattern[i++] = y;
@@ -518,7 +520,7 @@ ClearMem(life3dstruct * lp)
 /*-
  * This routine increments the values stored in the 27 cells centred on
  * (x,y,z) Note that the offset() macro implements wrapping - the world is a
- * torus.
+ * 4d torus
  */
 static Bool
 IncrementNbrs3D(life3dstruct * lp, CellList * cell)
@@ -680,7 +682,7 @@ static Bool
 GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 {
 	life3dstruct *lp = &life3ds[MI_SCREEN(mi)];
-	int         x, y, z;
+	int         x, y, z, orient, temp;
 	char       *patptr = (char *) NULL;
 
 	if (filePattern) {
@@ -704,9 +706,35 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 				break;
 		}
 	}
+#ifdef DEBUG
+	orient = 0;
+#else
+	orient = NRAND(24);
+#endif
 	while ((x = *patptr++) != 127) {
 		y = *patptr++;
 		z = *patptr++;
+		if (orient >= 16) {
+			temp = x;
+			x = y;
+			y = z;
+			z = temp;
+		} else if (orient >= 8) {
+			temp = x;
+			x = z;
+			z = y;
+			y = temp;
+		}
+		if (orient % 8 >= 4) {
+			x = -x;
+		}
+		if (orient % 4 >= 2) {
+			y = -y;
+		}
+		if (orient % 2) {
+			z = -z;
+		}
+
 		x += lp->ncolumns / 2;
 		y += lp->nrows / 2;
 		z += lp->nstacks / 2;
@@ -1142,7 +1170,8 @@ r = 1;
 	return True;
 }
 
-void free_life3d(Display *display, life3dstruct *lp)
+static void
+free_life3d(Display *display, life3dstruct *lp)
 {
 	if (lp->eraserhead.next != NULL)
 		End3D(lp);
@@ -1169,7 +1198,7 @@ init_life3d(ModeInfo * mi)
 	lp->generation = 0;
 
 	parseRule(mi);
-	parseFile();
+	parseFile(mi);
 	if (allPatterns) {
 		lp->patterned_rule = NRAND(LIFE_RULES);
 		copyFromPatternedRule(&lp->param, lp->patterned_rule);
@@ -1220,7 +1249,7 @@ init_life3d(ModeInfo * mi)
 	/*lp->tablesMade = 0; */
 
 	if (MI_IS_FULLRANDOM(mi)) {
-		lp->wireframe = (NRAND(4) == 0);
+		lp->wireframe = (NRAND(8) == 0);
 	} else {
 		lp->wireframe = MI_IS_WIREFRAME(mi);
 	}
