@@ -2,7 +2,7 @@
 /* lyapunov --- animated lyapunov space */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)lyapunov.c	5.00 2000/11/01 xlockmore";
+static const char sccsid[] = "@(#)lyapunov.c	5.09 2003/06/30 xlockmore";
 
 #endif
 
@@ -28,6 +28,8 @@ static const char sccsid[] = "@(#)lyapunov.c	5.00 2000/11/01 xlockmore";
  * Magazine" Sep 1991 for more info.
  *
  * Revision History:
+ * 30-Jun-2003: Changed writeable mode to be more consistent with
+ *              xscreensaver's starfish
  * 01-Nov-2000: Allocation checks
  * 17-Dec-1998: Used mandelbrot.c as basis
  */
@@ -46,10 +48,8 @@ static const char sccsid[] = "@(#)lyapunov.c	5.00 2000/11/01 xlockmore";
 #define SMOOTH_COLORS
 #define WRITABLE_COLORS
 #include "xlockmore.h"		/* from the xscreensaver distribution */
-#include <X11/Xutil.h>
 #else /* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
-#include "vis.h"
 #include "color.h"
 #endif /* !STANDALONE */
 
@@ -58,13 +58,33 @@ static const char sccsid[] = "@(#)lyapunov.c	5.00 2000/11/01 xlockmore";
 #define MINPOWER 2
 #define DEF_INCREMENT  "1.00"
 /* 4.0 is best for seeing if a point is inside the set, 13 is better if
-** you want to get a pretty corona
-*/
+ * you want to get a pretty corona
+ */
 
 #define FLOATRAND(min,max) ((min)+((double) LRAND()/((double) MAXRAND))*((max)-(min)))
 
+#define DEF_CYCLE "True"
+
+static Bool cycle_p;
+
+static XrmOptionDescRec opts[] =
+{
+  {(char *) "-cycle", (char *) ".lyapunov.cycle", XrmoptionNoArg, (caddr_t) "on"},
+  {(char *) "+cycle", (char *) ".lyapunov.cycle", XrmoptionNoArg, (caddr_t) "off"}
+};
+
+static argtype vars[] =
+{
+  {(caddr_t *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE
+, t_Bool}
+};
+static OptionStruct desc[] =
+{
+  {(char *) "-/+cycle", (char *) "turn on/off colour cycling"}
+};
+
 ModeSpecOpt lyapunov_opts =
-{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
+{sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
 ModStruct   lyapunov_description =
@@ -84,21 +104,20 @@ static int debug;
 
 typedef struct {
 	int         column;
-	Bool        backwards, reverse;
-	XColor      fgcol, bgcol;	/* foreground and background colour specs */
-	Bool        fixed_colormap;
+	Bool        backwards, cycle_p, mono_p, no_colors;
 	int         ncolors;
-	XColor      top;
-	XColor      bottom;
-	XColor     *colors;
-	Colormap    cmap;
-	int         usable_colors;
 	unsigned int cur_color;
+	GC          gc;
+	Colormap    cmap;
+	unsigned long blackpixel, whitepixel, fg, bg;
+	int direction;
+	XColor     *colors;
 	int         screen_width;
 	int         screen_height;
 	float       reptop;
 	unsigned long periodic_forcing;
 	int firstone;
+	ModeInfo   *mi;
 } lyapstruct;
 
 static lyapstruct *lyaps = (lyapstruct *) NULL;
@@ -133,22 +152,41 @@ reps(unsigned long periodic_forcing, int firstone, int iter, double a, double b)
 static void
 free_lyapunov(Display *display, lyapstruct *lp)
 {
-	if (lp->cmap != None) {
-		XFreeColormap(display, lp->cmap);
-		lp->cmap = None;
+	ModeInfo *mi = lp->mi;
+
+	if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+		MI_WHITE_PIXEL(mi) = lp->whitepixel;
+		MI_BLACK_PIXEL(mi) = lp->blackpixel;
+#ifndef STANDALONE
+		MI_FG_PIXEL(mi) = lp->fg;
+		MI_BG_PIXEL(mi) = lp->bg;
+#endif
+		if (lp->colors != NULL) {
+			if (lp->ncolors && !lp->no_colors)
+				free_colors(display, lp->cmap, lp->colors,
+					lp->ncolors);
+				free(lp->colors);
+				lp->colors = (XColor *) NULL;
+		}
+		if (lp->cmap != None) {
+			XFreeColormap(display, lp->cmap);
+			lp->cmap = None;
+		}
 	}
-	if (lp->colors != NULL) {
-		XFree((caddr_t) lp->colors);
-		lp->colors = (XColor *) NULL;
+	if (lp->gc != None) {
+		XFreeGC(display, lp->gc);
+		lp->gc = None;
 	}
 }
 
+#ifndef STANDALONE
+extern char *background;
+extern char *foreground;
+#endif
+
 void
 init_lyapunov(ModeInfo * mi)
 {
-	int         preserve;
-	Bool        truecolor;
-	unsigned long redmask, greenmask, bluemask;
 	Window      window = MI_WINDOW(mi);
 	Display    *display = MI_DISPLAY(mi);
 	int i = NRAND(MAXPOWER);
@@ -161,13 +199,13 @@ init_lyapunov(ModeInfo * mi)
 			return;
 	}
 	lp = &lyaps[MI_SCREEN(mi)];
+	lp->mi = mi;
 
 #ifdef DEBUG
 	debug = MI_IS_DEBUG(mi);
 #endif
 	lp->screen_width = MI_WIDTH(mi);
 	lp->screen_height = MI_HEIGHT(mi);
-	lp->reverse = (Bool) (LRAND() & 1);
 	lp->backwards = (Bool) (LRAND() & 1);
 	if (lp->backwards)
 		lp->column = lp->screen_width - 1;
@@ -207,65 +245,131 @@ init_lyapunov(ModeInfo * mi)
 		}
 	}
 
+	if (!lp->gc) {
+		if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+			XColor      color;
+
 #ifndef STANDALONE
-	lp->fixed_colormap = !setupColormap(mi,
-		&(lp->ncolors), &truecolor, &redmask, &greenmask, &bluemask);
-	if (!lp->fixed_colormap) {
-		preserve = preserveColors(MI_BLACK_PIXEL(mi), MI_WHITE_PIXEL(mi),
-					  MI_BG_PIXEL(mi), MI_FG_PIXEL(mi));
-		lp->bgcol.pixel = MI_BG_PIXEL(mi);
-		lp->fgcol.pixel = MI_FG_PIXEL(mi);
-		XQueryColor(display, MI_COLORMAP(mi), &(lp->bgcol));
-		XQueryColor(display, MI_COLORMAP(mi), &(lp->fgcol));
-
-#define RANGE 65536
-#define DENOM 4
-		/* color in the bottom part */
-		lp->bottom.red = NRAND(RANGE / DENOM);
-		lp->bottom.blue = NRAND(RANGE / DENOM);
-		lp->bottom.green = NRAND(RANGE / DENOM);
-		/* color in the top part */
-		lp->top.red = RANGE - NRAND(((DENOM-1)*RANGE) / DENOM);
-		lp->top.blue = RANGE - NRAND(((DENOM-1)*RANGE) / DENOM);
-		lp->top.green = RANGE - NRAND(((DENOM-1)*RANGE) / DENOM);
-
-		/* allocate colormap, if needed */
-		if (lp->colors == NULL)
-			if ((lp->colors = (XColor *) malloc(sizeof (XColor) *
-					lp->ncolors)) == NULL) {
-				free_lyapunov(display, lp);
-				return;
-			}
-		if (lp->cmap == None)
-			if ((lp->cmap = XCreateColormap(display, window,
-					MI_VISUAL(mi), AllocAll)) == None) {
-				free_lyapunov(display, lp);
-				return;
-			}
-		lp->usable_colors = lp->ncolors - preserve;
-	}
-
-#endif /* !STANDALONE */
-}
-
-#if !defined(OLD_COLOR)
-static unsigned short
-pick_rgb(unsigned short bottom,unsigned short top,
-	int color_ind,int ncolors)
-{
-	/* por == part of range */
-	double por;
-
-	if (color_ind<ncolors/2) {
-		/* going up */
-		por = ((float)color_ind*2) / ncolors;
-	} else {
-		/* going down */
-		por = ((float)(color_ind-ncolors/2)*2) / ncolors;
-	}
-	return ((unsigned short) (bottom + (top - bottom)*por));
-}
+			lp->fg = MI_FG_PIXEL(mi);
+			lp->bg = MI_BG_PIXEL(mi);
 #endif
+			lp->blackpixel = MI_BLACK_PIXEL(mi);
+			lp->whitepixel = MI_WHITE_PIXEL(mi);
+			if ((lp->cmap = XCreateColormap(display, window,
+					MI_VISUAL(mi), AllocNone)) == None) {
+				free_lyapunov(display, lp);
+				return;
+			}
+			XSetWindowColormap(display, window, lp->cmap);
+			(void) XParseColor(display, lp->cmap, "black", &color);
+			(void) XAllocColor(display, lp->cmap, &color);
+			MI_BLACK_PIXEL(mi) = color.pixel;
+			(void) XParseColor(display, lp->cmap, "white", &color);
+			(void) XAllocColor(display, lp->cmap, &color);
+			MI_WHITE_PIXEL(mi) = color.pixel;
+#ifndef STANDALONE
+			(void) XParseColor(display, lp->cmap, background, &color);
+			(void) XAllocColor(display, lp->cmap, &color);
+			MI_BG_PIXEL(mi) = color.pixel;
+			(void) XParseColor(display, lp->cmap, foreground, &color);
+			(void) XAllocColor(display, lp->cmap, &color);
+			MI_FG_PIXEL(mi) = color.pixel;
+#endif
+			lp->colors = (XColor *) NULL;
+			lp->ncolors = 0;
+		}
+		if ((lp->gc = XCreateGC(display, MI_WINDOW(mi),
+			     (unsigned long) 0, (XGCValues *) NULL)) == None) {
+			free_lyapunov(display, lp);
+			return;
+		}
+	}
+	MI_CLEARWINDOW(mi);
+ 
+  /* Set up colour map */
+  lp->direction = (LRAND() & 1) ? 1 : -1;
+  if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+    if (lp->colors != NULL) {
+      if (lp->ncolors && !lp->no_colors)
+        free_colors(display, lp->cmap, lp->colors, lp->ncolors);
+      free(lp->colors);
+      lp->colors = (XColor *) NULL;
+    }
+    lp->ncolors = MI_NCOLORS(mi);
+    if (lp->ncolors < 2)
+      lp->ncolors = 2;
+    if (lp->ncolors <= 2)
+      lp->mono_p = True;
+    else
+      lp->mono_p = False;
+
+    if (lp->mono_p)
+      lp->colors = (XColor *) NULL;
+    else
+      if ((lp->colors = (XColor *) malloc(sizeof (*lp->colors) *
+          (lp->ncolors + 1))) == NULL) {
+        free_lyapunov(display, lp);
+        return;
+      }
+    lp->cycle_p = has_writable_cells(mi);
+    if (lp->cycle_p) {
+      if (MI_IS_FULLRANDOM(mi)) {
+        if (!NRAND(8))
+          lp->cycle_p = False;
+        else
+          lp->cycle_p = True;
+      } else {
+        lp->cycle_p = cycle_p;
+      }
+    }
+    if (!lp->mono_p) {
+      if (!(LRAND() % 10))
+        make_random_colormap(
+#if STANDALONE
+            display, MI_WINDOW(mi),
+#else
+            mi,
+#endif
+              lp->cmap, lp->colors, &lp->ncolors,
+              True, True, &lp->cycle_p);
+      else if (!(LRAND() % 2))
+        make_uniform_colormap(
+#if STANDALONE
+            display, MI_WINDOW(mi),
+#else
+            mi,
+#endif
+                  lp->cmap, lp->colors, &lp->ncolors,
+                  True, &lp->cycle_p);
+      else
+        make_smooth_colormap(
+#if STANDALONE
+            display, MI_WINDOW(mi),
+#else
+            mi,
+#endif
+                 lp->cmap, lp->colors, &lp->ncolors,
+                 True, &lp->cycle_p);
+    }
+    XInstallColormap(display, lp->cmap);
+    if (lp->ncolors < 2) {
+      lp->ncolors = 2;
+      lp->no_colors = True;
+    } else
+      lp->no_colors = False;
+    if (lp->ncolors <= 2)
+      lp->mono_p = True;
+
+    if (lp->mono_p)
+      lp->cycle_p = False;
+
+  }
+  if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+                if (lp->mono_p) {
+			lp->cur_color = MI_BLACK_PIXEL(mi);
+		}
+  }
+}
 
 void
 draw_lyapunov(ModeInfo * mi)
@@ -273,96 +377,40 @@ draw_lyapunov(ModeInfo * mi)
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
 	GC          gc = MI_GC(mi);
-	int         h, j;
-	unsigned int i;
+	int         h;
 	lyapstruct *lp;
 
 	if (lyaps == NULL)
 		return;
 	lp = &lyaps[MI_SCREEN(mi)];
-	if (!lp->fixed_colormap && lp->colors == NULL)
-		return;
 
 	MI_IS_DRAWN(mi) = True;
 
-#ifndef STANDALONE
-	if (lp->column % 15 == 0) {
-		/* advance "drawing" color */
-		lp->cur_color = (lp->cur_color + 1) % lp->ncolors;
-		if (!lp->fixed_colormap && lp->usable_colors > 2) {
-			while (lp->cur_color == MI_WHITE_PIXEL(mi) ||
-			       lp->cur_color == MI_BLACK_PIXEL(mi) ||
-			       lp->cur_color == MI_BG_PIXEL(mi) ||
-			       lp->cur_color == MI_FG_PIXEL(mi)) {
-				lp->cur_color = (lp->cur_color + 1) % lp->ncolors;
-			}
-		}
-		/* advance colormap */
-		if (!lp->fixed_colormap && lp->usable_colors > 2) {
-			for (i = 0, j = lp->cur_color;
-			     i < (unsigned int) lp->ncolors; i++) {
-				if (i == MI_WHITE_PIXEL(mi)) {
-					lp->colors[i].pixel = i;
-					lp->colors[i].red = 65535;
-					lp->colors[i].blue = 65535;
-					lp->colors[i].green = 65535;
-					lp->colors[i].flags = DoRed | DoGreen | DoBlue;
-				} else if (i == MI_BLACK_PIXEL(mi)) {
-					lp->colors[i].pixel = i;
-					lp->colors[i].red = 0;
-					lp->colors[i].blue = 0;
-					lp->colors[i].green = 0;
-					lp->colors[i].flags = DoRed | DoGreen | DoBlue;
-				} else if (i == MI_BG_PIXEL(mi)) {
-					lp->colors[i] = lp->bgcol;
-				} else if (i == MI_FG_PIXEL(mi)) {
-					lp->colors[i] = lp->fgcol;
-				} else {
-#if defined(OLD_COLOR)
-					/* this is known to work well enough. I just wanted
-					** to explore some other possibilities
-					*/
-					double      range;
-					lp->colors[i].pixel = i;
-					range = ((double) (lp->top.red - lp->bottom.red)) /
-						lp->ncolors;
-					lp->colors[i].red = (short unsigned int) (range * j +
-							     lp->bottom.red);
-					range = ((double) (lp->top.green - lp->bottom.green)) /
-						lp->ncolors;
-					lp->colors[i].green = (short unsigned int) (range * j +
-							   lp->bottom.green);
-					range = ((double) (lp->top.blue - lp->bottom.blue)) /
-						lp->ncolors;
-					lp->colors[i].blue = (short unsigned int) (range * j +
-							    lp->bottom.blue);
-					lp->colors[i].flags = DoRed | DoGreen | DoBlue;
-					if (lp->reverse)
-						j = (j + 1) % lp->ncolors;
-					else
-						j = (j - 1 + lp->ncolors) % lp->ncolors;
-#else
-					lp->colors[i].pixel = i;
-					lp->colors[i].red = pick_rgb(lp->bottom.red,lp->top.red,
-						j,lp->ncolors);
-					lp->colors[i].green = pick_rgb(lp->bottom.green,lp->top.green,
-						j,lp->ncolors);
-					lp->colors[i].blue = pick_rgb(lp->bottom.blue,lp->top.blue,
-						j,lp->ncolors);
-					lp->colors[i].flags = DoRed | DoGreen | DoBlue;
-					if (lp->reverse)
-						j = (j + 1) % lp->ncolors;
-					else
-						j = (j - 1 + lp->ncolors) % lp->ncolors;
-#endif
-				}
-			}
-			/* make the entire lyapunov move forward */
-			XStoreColors(display, lp->cmap, lp->colors, lp->ncolors);
-			setColormap(display, window, lp->cmap, MI_IS_INWINDOW(mi));
-		}
-	}
-#endif /* !STANDALONE */
+        if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+                if (lp->mono_p) {
+                        XSetForeground(display, lp->gc, lp->cur_color);
+                } else {
+                        lp->cur_color = (lp->cur_color + 1) % lp->ncolors;
+                        XSetForeground(display, lp->gc, lp->colors[lp->cur_color].pixel);
+                }
+        } else {
+                if (MI_NPIXELS(mi) > 2)
+                        XSetForeground(display, lp->gc, MI_PIXEL(mi, lp->cur_color));
+                else if (lp->cur_color)
+                        XSetForeground(display, lp->gc, MI_BLACK_PIXEL(mi));
+                else
+                        XSetForeground(display, lp->gc, MI_WHITE_PIXEL(mi));
+                if (++lp->cur_color >= (unsigned int) MI_NPIXELS(mi))
+                        lp->cur_color = 0;
+        }
+
+  /* Rotate colours */
+  if (lp->cycle_p) {
+    rotate_colors(display, lp->cmap, lp->colors, lp->ncolors,
+      lp->direction);
+    if (!(LRAND() % 1000))
+      lp->direction = -lp->direction;
+  }
 	/* so we iterate columns beyond the width of the physical screen,
         ** so that we just wait around and show what we've done
 	*/
@@ -399,18 +447,7 @@ draw_lyapunov(ModeInfo * mi)
 		else {
 			color=(unsigned int) ((MI_NPIXELS(mi) * (float)-result) / lp->reptop);
 			color = color % MI_NPIXELS(mi);
-#ifndef STANDALONE
-			if (!lp->fixed_colormap && lp->usable_colors > 2) {
-				while (color == MI_WHITE_PIXEL(mi) ||
-				       color == MI_BLACK_PIXEL(mi) ||
-				       color == MI_BG_PIXEL(mi) ||
-				       color == MI_FG_PIXEL(mi)) {
-					color = (color + 1) % lp->ncolors;
-				}
-				XSetForeground(display, gc, color);
-			} else
-				XSetForeground(display, gc, MI_PIXEL(mi, color));
-#endif /* !STANDALONE */
+			XSetForeground(display, gc, MI_PIXEL(mi, color));
 		}
 		/* we no longer have vertical symmetry - so we compute all points
 		** and do not draw with redundancy
