@@ -467,7 +467,7 @@ free_matrix(Display *display, matrix_t *mp)
 			XFreePixmap(display, mp->columns[c].pixmap);
 	  }
 
-	  (void) free((void *) mp->columns);
+	  free(mp->columns);
 	  mp->columns = (column_t *) NULL;
 	}
 
@@ -715,7 +715,7 @@ void release_matrix(ModeInfo *mi)
 
 	for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 		free_matrix(MI_DISPLAY(mi), &matrix[screen]);
-	  (void) free((void *) matrix);
+	  free(matrix);
 	  matrix = (matrix_t *) NULL;
   }
 }
