@@ -892,7 +892,7 @@ release_nose(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_nose(MI_DISPLAY(mi), &noses[screen]);
-		(void) free((void *) noses);
+		free(noses);
 		noses = (nosestruct *) NULL;
 	}
 	if (mode_font != None) {
