@@ -108,7 +108,7 @@ ModStruct   pacman_description = {
 	"draw_pacman", 		/* *callback_name; */
 	"release_pacman",	/* *release_name; */
  	"refresh_pacman", 	/* *refresh_name; */
-	"init_pacman", 		/* *change_name; */
+	"change_pacman", 	/* *change_name; */
 	(char *) NULL, 		/* *unused_name; */
 	&pacman_opts,		/* *msopts */
  	10000, 4, 1, 0, 64, 1.0, "", "Shows Pacman(tm)", 0, NULL
@@ -121,21 +121,21 @@ free_pacman(Display *display, pacmangamestruct *pp)
 	int         dir, mouth;
 
 	if (pp->ghosts != NULL) {
-		(void) free((void *) pp->ghosts);
+		free(pp->ghosts);
 		pp->ghosts = (ghoststruct *) NULL;
 	}
 	if (pp->stippledGC != None) {
-		(void)XFreeGC(display, pp->stippledGC);
+		XFreeGC(display, pp->stippledGC);
 		pp->stippledGC = None;
 	}
 	if (pp->ghostPixmap != None) {
-		(void)XFreePixmap(display, pp->ghostPixmap);
+		XFreePixmap(display, pp->ghostPixmap);
 		pp->ghostPixmap = None;
 	}
 	for (dir = 0; dir < 4; dir++)
 		for (mouth = 0; mouth < MAXMOUTH; mouth++)
 			if (pp->pacmanPixmap[dir][mouth] != None) {
-				(int)XFreePixmap(display, 
+				XFreePixmap(display, 
 					pp->pacmanPixmap[dir][mouth]);
 				pp->pacmanPixmap[dir][mouth] = None;
 			}
@@ -169,10 +169,10 @@ check_death(ModeInfo * mi, pacmangamestruct *pp)
 		     (pp->ghosts[ghost].row == pp->pacman.nextrow) &&
 		     (pp->ghosts[ghost].col == pp->pacman.nextcol))) {
 			pp->ghosts[ghost].dead = 1;
-			(void)XSetForeground(display, 
+			XSetForeground(display, 
 					     pp->stippledGC, 
 					     MI_BLACK_PIXEL(mi));
-			(void)XFillRectangle(display, window, 
+			XFillRectangle(display, window, 
 					    pp->stippledGC,
 					    pp->ghosts[ghost].cf, 
 					    pp->ghosts[ghost].rf, 
@@ -250,10 +250,10 @@ setwallcolor(ModeInfo * mi)
 	pacmangamestruct *pp = &pacmangames[MI_SCREEN(mi)];
 
 	if (MI_NPIXELS(mi) > 2)
-		(void)XSetForeground(display, pp->stippledGC, 
+		XSetForeground(display, pp->stippledGC, 
 				MI_PIXEL(mi, BLUE));
 	else
-		(void)XSetForeground(display, pp->stippledGC, 
+		XSetForeground(display, pp->stippledGC, 
 				MI_WHITE_PIXEL(mi));
 }
 
@@ -264,7 +264,7 @@ setdotcolor(ModeInfo * mi)
 	Display    *display = MI_DISPLAY(mi);
 	pacmangamestruct *pp = &pacmangames[MI_SCREEN(mi)];
 
-	(void)XSetForeground(display, pp->stippledGC, 
+	XSetForeground(display, pp->stippledGC, 
 			MI_WHITE_PIXEL(mi));
 }
 
@@ -280,8 +280,8 @@ drawlevelblock(ModeInfo * mi, pacmangamestruct *pp,
 	if (pp->xs % 2 == 1) dx = -1;
 	if (pp->ys % 2 == 1) dy = -1;
 
-	(void)XSetFillStyle(display, pp->stippledGC, FillSolid);
-	(void)XSetLineAttributes(display, pp->stippledGC, pp->wallwidth,
+	XSetFillStyle(display, pp->stippledGC, FillSolid);
+	XSetLineAttributes(display, pp->stippledGC, pp->wallwidth,
 			LineSolid, CapRound, JoinMiter);
 
 	if (pp->xs < 2 || pp->ys < 2) {
@@ -424,11 +424,11 @@ draw_pacman_sprite(ModeInfo * mi)
 	dir = (ABS(pp->pacman.cfactor) * (2 - pp->pacman.cfactor) +
 	       ABS(pp->pacman.rfactor) * (1 + pp->pacman.rfactor)) % 4;
 
-	(void)XSetForeground(display, pp->stippledGC, 
+	XSetForeground(display, pp->stippledGC, 
 			     MI_BLACK_PIXEL(mi));
 	if (pp->pacman.oldcf != NOWHERE && pp->pacman.oldrf != NOWHERE) {
 #ifdef FLASH
-		(void)XFillRectangle(display, window, pp->stippledGC,
+		XFillRectangle(display, window, pp->stippledGC,
 			     pp->pacman.oldcf, pp->pacman.oldrf, 
 			     pp->spritexs, pp->spriteys);
 #else
@@ -439,28 +439,28 @@ draw_pacman_sprite(ModeInfo * mi)
 #endif
 	}
 
-	(void)XSetTSOrigin(display, pp->stippledGC, 
+	XSetTSOrigin(display, pp->stippledGC, 
 			   pp->pacman.cf, pp->pacman.rf);
 	if (MI_NPIXELS(mi) > 2)
-		(void)XSetForeground(display, pp->stippledGC, 
+		XSetForeground(display, pp->stippledGC, 
 				     MI_PIXEL(mi, YELLOW));
 	else
-		(void)XSetForeground(display, pp->stippledGC, 
+		XSetForeground(display, pp->stippledGC, 
 				     MI_WHITE_PIXEL(mi));
 
-	(void)XSetStipple(display, pp->stippledGC,
+	XSetStipple(display, pp->stippledGC,
 		    pp->pacmanPixmap[dir][pp->pacman.mouthstage]);
 #ifdef FLASH
-	(void)XSetFillStyle(display, pp->stippledGC, FillStippled);
+	XSetFillStyle(display, pp->stippledGC, FillStippled);
 #else
-	(void)XSetFillStyle(display, pp->stippledGC, 
+	XSetFillStyle(display, pp->stippledGC, 
 			    FillOpaqueStippled);
 #endif
 	if (pp->xs < 2 || pp->ys < 2)
 		XDrawPoint(display, window, pp->stippledGC,
 				pp->pacman.cf, pp->pacman.rf);
 	else
-		(void)XFillRectangle(display, window, pp->stippledGC,
+		XFillRectangle(display, window, pp->stippledGC,
 			       pp->pacman.cf, pp->pacman.rf, 
 			       pp->spritexs, pp->spriteys);
 	pp->pacman.mouthstage += pp->pacman.mouthdirection;
@@ -487,14 +487,14 @@ draw_ghost_sprite(ModeInfo * mi, const unsigned ghost) {
 		pp->ghosts[ghost].row * pp->ys + pp->ghosts[ghost].delta.y * 
 		pp->ghosts[ghost].rfactor + pp->yb + pp->spritedy;
 	
-	(void)XSetForeground(display, 
+	XSetForeground(display, 
 			     pp->stippledGC, 
 			     MI_BLACK_PIXEL(mi));
 
 	if (pp->ghosts[ghost].oldcf != NOWHERE ||
 		pp->ghosts[ghost].oldrf != NOWHERE) {
 #ifdef FLASH
-		(void)XFillRectangle(display, window, 
+		XFillRectangle(display, window, 
 				    pp->stippledGC, pp->ghosts[ghost].oldcf, 
 				    pp->ghosts[ghost].oldrf, 
 				    pp->spritexs, pp->spriteys);
@@ -510,27 +510,27 @@ draw_ghost_sprite(ModeInfo * mi, const unsigned ghost) {
 		(unsigned int)pp->ghosts[ghost].col, 
 		(unsigned int)pp->ghosts[ghost].row);
 
-	(void)XSetTSOrigin(display, pp->stippledGC,
+	XSetTSOrigin(display, pp->stippledGC,
 		pp->ghosts[ghost].cf, pp->ghosts[ghost].rf);
 
 	if (MI_NPIXELS(mi) > 2)
-		(void)XSetForeground(display, 
+		XSetForeground(display, 
 		     pp->stippledGC, 
 		     MI_PIXEL(mi, GREEN));
 	else
-		(void)XSetForeground(display, 
+		XSetForeground(display, 
 		     pp->stippledGC, 
 		     MI_WHITE_PIXEL(mi));
 
-	(void)XSetStipple(display, pp->stippledGC, 
+	XSetStipple(display, pp->stippledGC, 
 			  pp->ghostPixmap);
 
 #ifdef FLASH
-	(void)XSetFillStyle(display, 
+	XSetFillStyle(display, 
 			    pp->stippledGC, 
 			    FillStippled);
 #else
-	(void)XSetFillStyle(display, 
+	XSetFillStyle(display, 
 			    pp->stippledGC, 
 			    FillOpaqueStippled);
 #endif
@@ -539,7 +539,7 @@ draw_ghost_sprite(ModeInfo * mi, const unsigned ghost) {
 				pp->ghosts[ghost].cf,
 				pp->ghosts[ghost].rf);
 	else
-		(void)XFillRectangle(display, 
+		XFillRectangle(display, 
 				     window, 
 				     pp->stippledGC,
 				     pp->ghosts[ghost].cf, 
@@ -593,7 +593,7 @@ init_pacman(ModeInfo * mi)
 	pp->width = (unsigned short)MI_WIDTH(mi);
 	pp->height = (unsigned short)MI_HEIGHT(mi);
 	if (pp->ghostPixmap != None) {
-		(void)XFreePixmap(display, pp->ghostPixmap);
+		XFreePixmap(display, pp->ghostPixmap);
 		pp->ghostPixmap = None;
 		pp->graphics_format = IS_NONE;
 	}
@@ -649,7 +649,7 @@ init_pacman(ModeInfo * mi)
 	gcv.background = 0;
 	if ((fg_gc = XCreateGC(display, pp->ghostPixmap,
 			GCForeground | GCBackground, &gcv)) == None) {
-		(void)XFreeGC(display, bg_gc);
+		XFreeGC(display, bg_gc);
 		free_pacman(display, pp);
 		return;
 	}
@@ -667,14 +667,14 @@ init_pacman(ModeInfo * mi)
 	SETPOINT(points[7], pp->spritexs,		pp->spriteys / 2);
 	SETPOINT(points[8], 1, 				pp->spriteys / 2);
 
-	(void)XFillRectangle(display, pp->ghostPixmap, bg_gc,
+	XFillRectangle(display, pp->ghostPixmap, bg_gc,
 		0, 0, pp->spritexs, pp->spriteys);
-	(void)XFillArc(display, pp->ghostPixmap, fg_gc,
+	XFillArc(display, pp->ghostPixmap, fg_gc,
 		0, 0, pp->spritexs, pp->spriteys, 0, 11520);
-	(void)XFillPolygon(display, pp->ghostPixmap, fg_gc,
+	XFillPolygon(display, pp->ghostPixmap, fg_gc,
 		points, 9, Nonconvex, CoordModeOrigin);
-	(void)XFreeGC(display, bg_gc);
-	(void)XFreeGC(display, fg_gc);
+	XFreeGC(display, bg_gc);
+	XFreeGC(display, fg_gc);
 
 	if (!pp->stippledGC) {
 		gcv.foreground = MI_BLACK_PIXEL(mi);
@@ -688,7 +688,7 @@ init_pacman(ModeInfo * mi)
 	if (pp->pacmanPixmap[0][0] != None)
 		for (dir = 0; dir < 4; dir++)
 			for (mouth = 0; mouth < MAXMOUTH; mouth++)
-				(void)XFreePixmap(display, 
+				XFreePixmap(display, 
 						  pp->pacmanPixmap[dir]
 						  	[mouth]);
 
@@ -715,27 +715,27 @@ init_pacman(ModeInfo * mi)
 						GCForeground | 
 						GCBackground, &gcv)) == 
 					None) {
-        			(void)XFreeGC(display, fg_gc);
-				(void)free_pacman(display, pp);
+        			XFreeGC(display, fg_gc);
+				free_pacman(display, pp);
 				return;
 			}
-			(void)XFillRectangle(display, 
+			XFillRectangle(display, 
 					pp->pacmanPixmap[dir][mouth], bg_gc,
 					0, 0, pp->spritexs, pp->spriteys);
 			if (pp->spritexs == 1 && pp->spriteys == 1)
-				(void)XFillRectangle(display, 
+				XFillRectangle(display, 
 					     pp->pacmanPixmap[dir][mouth], 
 					     fg_gc, 0, 0, pp->spritexs, 
 					     pp->spriteys);
 			else
-				(void)XFillArc(display, 
+				XFillArc(display, 
 					       pp->pacmanPixmap[dir][mouth],
 					       fg_gc,
 					0, 0, pp->spritexs, pp->spriteys,
 					((90 - dir * 90) + mouth * 5) * 64,
 					(360 + (-2 * mouth * 5)) * 64);
-			(void)XFreeGC(display, fg_gc);
-			(void)XFreeGC(display, bg_gc);
+			XFreeGC(display, fg_gc);
+			XFreeGC(display, bg_gc);
 		}
 
 	pp->pacman.lastbox = START;
@@ -744,7 +744,7 @@ init_pacman(ModeInfo * mi)
 	pp->pacman.nextrow = NOWHERE;
 
 	if (pp->ghosts != NULL) {
-			(void) free((void *) pp->ghosts);
+			free(pp->ghosts);
 			pp->ghosts = (ghoststruct *) NULL;
 	}
 	pp->nghosts = GHOSTS;
@@ -830,7 +830,7 @@ release_pacman(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_pacman(MI_DISPLAY(mi), &pacmangames[screen]);
-		(void) free((void *) pacmangames);
+		free(pacmangames);
 		pacmangames = (pacmangamestruct *) NULL;
 	}
 }
