@@ -246,6 +246,9 @@ static char write_modes[][MAXMODECHARS] =
 #ifdef MODE_crystal
 	"crystal",
 #endif
+#ifdef MODE_lyapunov
+	"lyapunov",
+#endif
 #ifdef MODE_mandelbrot
 	"mandelbrot",
 #endif
