@@ -264,18 +264,19 @@ static void nextdoorcolor(ModeInfo *mi, Door *door)
 	}
 }
 
-void free_scooter(scooterstruct *sp)
+static void
+free_scooter(scooterstruct *sp)
 {
 	if (sp->doors != NULL) {
-		(void) free((void *) sp->doors);
+		free(sp->doors);
 		sp->doors = (Door *) NULL;
 	}
 	if (sp->stars != NULL) {
-		(void) free((void *) sp->stars);
+		free(sp->stars);
 		sp->stars = (Star *) NULL;
 	}
 	if (sp->zelements != NULL) {
-		(void) free((void *) sp->zelements);
+		free(sp->zelements);
 		sp->zelements = (ZElement *) NULL;
 	}
 }
@@ -287,11 +288,11 @@ void release_scooter(ModeInfo *mi)
 
                 for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
                         free_scooter(&scooters[screen]);
-                (void) free((void *) scooters);
+                free(scooters);
                 scooters = (scooterstruct *) NULL;
         }
 	if (sintable != NULL) {
-		(void) free((void *) sintable);
+		free(sintable);
 		sintable = (float *) NULL;
 	}
 }
