@@ -2,7 +2,7 @@
 /* starfish ---  */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)starfish.c	5.00 2000/11/01 xlockmore";
+static const char sccsid[] = "@(#)starfish.c	5.03 2003/05/01 xlockmore";
 
 #endif
 
@@ -17,6 +17,7 @@ static const char sccsid[] = "@(#)starfish.c	5.00 2000/11/01 xlockmore";
  * implied warranty.
  *
  * Revision History:
+ * 01-May-2003: Changed to work in a 64x64 window.
  * 01-Nov-2000: Allocation checks
  * 24-Feb-1998: xlockmore version by Jouk Jansen <joukj@hrem.stm.tudelft.nl>
  * 1997: original xscreensaver version by Jamie Zawinski <jwz@jwz.org>
@@ -228,10 +229,9 @@ make_starfish(ModeInfo * mi)
 	sp->size *= SCALE;
 
 	sp->max_r = sp->size;
-	sp->min_r = 0;
+	sp->min_r = SCALE;
+	/* sp->min_r = 5 * SCALE; */
 
-	if (sp->min_r < (5 * SCALE))
-		sp->min_r = (5 * SCALE);
 	/* mid = ((sp->min_r + sp->max_r) / 2); */
 
 	sp->x = sp->winwidth / 2;
