@@ -356,7 +356,7 @@ t3d_turn(double feld1[], double feld2[], double winkel)
 static void
 t3d_projektion( ModeInfo* mi)
 {
-  double c1[3],c2[3],k[3],x1,y1;
+  double c1[3],c2[3],k[3],x_1,y_1;
   double cno,cnorm/*,magnit*/;
   int i;
    t3dstruct *t3dp;
@@ -388,15 +388,15 @@ t3d_projektion( ModeInfo* mi)
       t3d_vektorprodukt(c2,c1,k);
 
 
-      x1=(t3dp->startx+(t3dp->x[0]*k[0]+t3dp->x[1]*k[1]+t3dp->x[2]*k[2])*mag);
-      y1=(t3dp->starty-(t3dp->y[0]*k[0]+t3dp->y[1]*k[1]+t3dp->y[2]*k[2])*mag);
-      if(   (x1>-2000.0)
-	 && (x1<t3dp->width+2000.0)
-	 && (y1>-2000.0)
-	 && (y1<t3dp->height+2000.0))
+      x_1=(t3dp->startx+(t3dp->x[0]*k[0]+t3dp->x[1]*k[1]+t3dp->x[2]*k[2])*mag);
+      y_1=(t3dp->starty-(t3dp->y[0]*k[0]+t3dp->y[1]*k[1]+t3dp->y[2]*k[2])*mag);
+      if(   (x_1>-2000.0)
+	 && (x_1<t3dp->width+2000.0)
+	 && (y_1>-2000.0)
+	 && (y_1<t3dp->height+2000.0))
 	{
-	  t3dp->kugeln[i].x1=(int)x1;
-	  t3dp->kugeln[i].y1=(int)y1;
+	  t3dp->kugeln[i].x1=(int)x_1;
+	  t3dp->kugeln[i].y1=(int)y_1;
 	}
       else
 	{
