@@ -2,7 +2,7 @@
 /* tube --- animated tube */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)tube.c	5.00 2000/11/01 xlockmore";
+static const char sccsid[] = "@(#)tube.c	5.09 2003/06/30 xlockmore";
 
 #endif
 
@@ -22,6 +22,8 @@ static const char sccsid[] = "@(#)tube.c	5.00 2000/11/01 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
+ * 30-Jun-2003: Changed writeable mode to be more consistent with
+ *              xscreensaver's starfish
  * 01-Nov-2000: Allocation checks
  * 10-May-1997: Compatible with xscreensaver
  * 04-Mar-1997: Memory leak fix by Tom Schmidt <tschmidt@micron.com>
@@ -42,17 +44,34 @@ static const char sccsid[] = "@(#)tube.c	5.00 2000/11/01 xlockmore";
 #define SMOOTH_COLORS
 #define WRITABLE_COLORS
 #include "xlockmore.h"		/* from the xscreensaver distribution */
-#include <X11/Xutil.h>
 #else /* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
-#include "vis.h"
 #include "color.h"
 #endif /* !STANDALONE */
 
 #ifdef MODE_tube
 
+#define DEF_CYCLE "True"
+
+static Bool cycle_p;
+
+static XrmOptionDescRec opts[] =
+{
+  {(char *) "-cycle", (char *) ".tube.cycle", XrmoptionNoArg, (caddr_t) "on"},
+  {(char *) "+cycle", (char *) ".tube.cycle", XrmoptionNoArg, (caddr_t) "off"}
+};
+
+static argtype vars[] =
+{
+  {(caddr_t *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool}
+};
+static OptionStruct desc[] =
+{
+  {(char *) "-/+cycle", (char *) "turn on/off colour cycling"}
+};
+
 ModeSpecOpt tube_opts =
-{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
+{sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
 ModStruct   tube_description =
@@ -73,15 +92,15 @@ typedef struct {
 	int         shape;
 	XPoint     *pts, *proto_pts;
 	unsigned int cur_color;
+	GC          gc;
 	Colormap    cmap;
+	unsigned long blackpixel, whitepixel, fg, bg;
+	int direction;
 	XColor     *colors;
-	XColor      top;
-	XColor      bottom;
-	XColor      bgcol, fgcol;	/* foreground and background colour specs */
 	int         counter;
 	int         ncolors;
-	int         usable_colors;
-	Bool        fixed_colormap, reverse;
+	Bool        cycle_p, mono_p, no_colors, reverse;
+	ModeInfo   *mi;
 } tubestruct;
 
 static tubestruct *tubes = (tubestruct *) NULL;
@@ -102,27 +121,47 @@ free_pts(tubestruct *tp)
 static void
 free_tube(Display *display,  tubestruct *tp)
 {
-	free_pts(tp);
-	if (tp->cmap != None) {
-		XFreeColormap(display, tp->cmap);
-		tp->cmap = None;
-	}
-	if (tp->colors != NULL) {
-		XFree((caddr_t) tp->colors);
-		tp->colors = (XColor *) NULL;
-	}
+  ModeInfo *mi = tp->mi;
+
+  free_pts(tp);
+
+  if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+    MI_WHITE_PIXEL(mi) = tp->whitepixel;
+    MI_BLACK_PIXEL(mi) = tp->blackpixel;
+#ifndef STANDALONE
+    MI_FG_PIXEL(mi) = tp->fg;
+    MI_BG_PIXEL(mi) = tp->bg;
+#endif
+    if (tp->colors != NULL) {
+      if (tp->ncolors && !tp->no_colors)
+        free_colors(display, tp->cmap, tp->colors, tp->ncolors);
+      free(tp->colors);
+      tp->colors = (XColor *) NULL;
+    }
+    if (tp->cmap != None) {
+      XFreeColormap(display, tp->cmap);
+      tp->cmap = None;
+    }
+  }
+  if (tp->gc != None) {
+     XFreeGC(display, tp->gc);
+     tp->gc = None;
+  }
 }
 
+#ifndef STANDALONE
+extern char *background;
+extern char *foreground;
+#endif
+
 void
 init_tube(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
-	int         screen_width, screen_height, preserve;
+	int         screen_width, screen_height;
 	int         size = MI_SIZE(mi);
-	Bool        truecolor;
 	int         star = 1, lw;
-	unsigned long redmask, greenmask, bluemask;
 	tubestruct *tp;
 
 	if (tubes == NULL) {
@@ -131,6 +170,7 @@ init_tube(ModeInfo * mi)
 			return;
 	}
 	tp = &tubes[MI_SCREEN(mi)];
+	tp->mi = mi;
 
 	screen_width = MI_WIDTH(mi);
 	screen_height = MI_HEIGHT(mi);
@@ -201,47 +241,130 @@ init_tube(ModeInfo * mi)
 
 	tp->counter = 0;
 
-	MI_CLEARWINDOW(mi);
+	if (!tp->gc) {
+		if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+			XColor      color;
 
 #ifndef STANDALONE
-	tp->fixed_colormap = !setupColormap(mi,
-		&(tp->ncolors), &truecolor, &redmask, &greenmask, &bluemask);
-	if (!tp->fixed_colormap) {
-		preserve = preserveColors(MI_BLACK_PIXEL(mi), MI_WHITE_PIXEL(mi),
-					  MI_BG_PIXEL(mi), MI_FG_PIXEL(mi));
-		tp->bgcol.pixel = MI_BG_PIXEL(mi);
-		tp->fgcol.pixel = MI_FG_PIXEL(mi);
-		XQueryColor(display, MI_COLORMAP(mi), &(tp->bgcol));
-		XQueryColor(display, MI_COLORMAP(mi), &(tp->fgcol));
-
-#define RANGE 65536
-#define DENOM 2
-		/* color in the bottom part */
-		tp->bottom.red = NRAND(RANGE / DENOM);
-		tp->bottom.blue = NRAND(RANGE / DENOM);
-		tp->bottom.green = NRAND(RANGE / DENOM);
-		/* color in the top part */
-		tp->top.red = RANGE - NRAND(RANGE / DENOM);
-		tp->top.blue = RANGE - NRAND(RANGE / DENOM);
-		tp->top.green = RANGE - NRAND(RANGE / DENOM);
-
-		/* allocate colormap, if needed */
-		if (tp->colors == NULL)
-			if ((tp->colors = (XColor *) malloc(sizeof (XColor) *
-					tp->ncolors)) == NULL) {
-				free_tube(display, tp);
-				return;
-			}
-		if (tp->cmap == None)
+			tp->fg = MI_FG_PIXEL(mi);
+			tp->bg = MI_BG_PIXEL(mi);
+#endif
+			tp->blackpixel = MI_BLACK_PIXEL(mi);
+			tp->whitepixel = MI_WHITE_PIXEL(mi);
 			if ((tp->cmap = XCreateColormap(display, window,
-						   MI_VISUAL(mi), AllocAll)) == None) {
+					MI_VISUAL(mi), AllocNone)) == None) {
 				free_tube(display, tp);
 				return;
 			}
-		tp->usable_colors = tp->ncolors - preserve;
+			XSetWindowColormap(display, window, tp->cmap);
+			(void) XParseColor(display, tp->cmap, "black", &color);
+			(void) XAllocColor(display, tp->cmap, &color);
+			MI_BLACK_PIXEL(mi) = color.pixel;
+			(void) XParseColor(display, tp->cmap, "white", &color);
+			(void) XAllocColor(display, tp->cmap, &color);
+			MI_WHITE_PIXEL(mi) = color.pixel;
+#ifndef STANDALONE
+			(void) XParseColor(display, tp->cmap, background, &color);
+			(void) XAllocColor(display, tp->cmap, &color);
+			MI_BG_PIXEL(mi) = color.pixel;
+			(void) XParseColor(display, tp->cmap, foreground, &color);
+			(void) XAllocColor(display, tp->cmap, &color);
+			MI_FG_PIXEL(mi) = color.pixel;
+#endif
+			tp->colors = (XColor *) NULL;
+			tp->ncolors = 0;
+		}
+		if ((tp->gc = XCreateGC(display, MI_WINDOW(mi),
+			     (unsigned long) 0, (XGCValues *) NULL)) == None) {
+			free_tube(display, tp);
+			return;
+		}
 	}
-	tp->cur_color = NRAND(tp->ncolors);
-#endif /* !STANDALONE */
+	MI_CLEARWINDOW(mi);
+ 
+  /* Set up colour map */
+  tp->direction = (LRAND() & 1) ? 1 : -1;
+  if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+    if (tp->colors != NULL) {
+      if (tp->ncolors && !tp->no_colors)
+        free_colors(display, tp->cmap, tp->colors, tp->ncolors);
+      free(tp->colors);
+      tp->colors = (XColor *) NULL;
+    }
+    tp->ncolors = MI_NCOLORS(mi);
+    if (tp->ncolors < 2)
+      tp->ncolors = 2;
+    if (tp->ncolors <= 2)
+      tp->mono_p = True;
+    else
+      tp->mono_p = False;
+
+    if (tp->mono_p)
+      tp->colors = (XColor *) NULL;
+    else
+      if ((tp->colors = (XColor *) malloc(sizeof (*tp->colors) *
+          (tp->ncolors + 1))) == NULL) {
+        free_tube(display, tp);
+        return;
+      }
+    tp->cycle_p = has_writable_cells(mi);
+    if (tp->cycle_p) {
+      if (MI_IS_FULLRANDOM(mi)) {
+        if (!NRAND(8))
+          tp->cycle_p = False;
+        else
+          tp->cycle_p = True;
+      } else {
+        tp->cycle_p = cycle_p;
+      }
+    }
+    if (!tp->mono_p) {
+      if (!(LRAND() % 10))
+        make_random_colormap(
+#if STANDALONE
+            display, MI_WINDOW(mi),
+#else
+            mi,
+#endif
+              tp->cmap, tp->colors, &tp->ncolors,
+              True, True, &tp->cycle_p);
+      else if (!(LRAND() % 2))
+        make_uniform_colormap(
+#if STANDALONE
+            display, MI_WINDOW(mi),
+#else
+            mi,
+#endif
+                  tp->cmap, tp->colors, &tp->ncolors,
+                  True, &tp->cycle_p);
+      else
+        make_smooth_colormap(
+#if STANDALONE
+            display, MI_WINDOW(mi),
+#else
+            mi,
+#endif
+                 tp->cmap, tp->colors, &tp->ncolors,
+                 True, &tp->cycle_p);
+    }
+    XInstallColormap(display, tp->cmap);
+    if (tp->ncolors < 2) {
+      tp->ncolors = 2;
+      tp->no_colors = True;
+    } else
+      tp->no_colors = False;
+    if (tp->ncolors <= 2)
+      tp->mono_p = True;
+
+    if (tp->mono_p)
+      tp->cycle_p = False;
+
+  }
+  if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+                if (tp->mono_p) {
+			tp->cur_color = MI_BLACK_PIXEL(mi);
+		}
+  }
 }
 
 void
@@ -249,38 +372,49 @@ draw_tube(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
-	GC          gc = MI_GC(mi);
-	unsigned int i, j;
+	unsigned int i;
 	int         lw;
 	tubestruct *tp;
 
 	if (tubes == NULL)
 		return;
 	tp = &tubes[MI_SCREEN(mi)];
-#ifndef STANDALONE
-	if (!tp->fixed_colormap && tp->cmap == None)
+
+	if (tp->no_colors) {
+		init_tube(mi);
 		return;
-#endif
+	}
 	if (tp->shape >= 3 && tp->pts == NULL)
 		return;
 
 	MI_IS_DRAWN(mi) = True;
 	lw = tp->linewidth / 2;
 
-	/* advance drawing color */
-	tp->cur_color = (tp->cur_color + 1) % tp->ncolors;
-#ifndef STANDALONE
-	if (!tp->fixed_colormap && tp->usable_colors > 2) {
-		while (tp->cur_color == MI_WHITE_PIXEL(mi) ||
-		       tp->cur_color == MI_BLACK_PIXEL(mi) ||
-		       tp->cur_color == MI_BG_PIXEL(mi) ||
-		       tp->cur_color == MI_FG_PIXEL(mi)) {
-			tp->cur_color = (tp->cur_color + 1) % tp->ncolors;
-		}
-		XSetForeground(display, gc, tp->cur_color);
-	} else
-		XSetForeground(display, gc, MI_PIXEL(mi, tp->cur_color));
-#endif /* !STANDALONE */
+        if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+                if (tp->mono_p) {
+                        XSetForeground(display, tp->gc, tp->cur_color);
+                } else {
+                        tp->cur_color = (tp->cur_color + 1) % tp->ncolors;
+                        XSetForeground(display, tp->gc, tp->colors[tp->cur_color].pixel);
+                }
+        } else {
+                if (MI_NPIXELS(mi) > 2)
+                        XSetForeground(display, tp->gc, MI_PIXEL(mi, tp->cur_color));
+                else if (tp->cur_color)
+                        XSetForeground(display, tp->gc, MI_BLACK_PIXEL(mi));
+                else
+                        XSetForeground(display, tp->gc, MI_WHITE_PIXEL(mi));
+                if (++tp->cur_color >= (unsigned int) MI_NPIXELS(mi))
+                        tp->cur_color = 0;
+        }
+
+  /* Rotate colours */
+  if (tp->cycle_p) {
+    rotate_colors(display, tp->cmap, tp->colors, tp->ncolors,
+      tp->direction);
+    if (!(LRAND() % 1000))
+      tp->direction = -tp->direction;
+  }
 
 	/* move rectangle forward, horiz */
 	tp->x1 += tp->dx1;
@@ -302,78 +436,24 @@ draw_tube(ModeInfo * mi)
 		tp->y1 = MI_HEIGHT(mi) - tp->height - 1 - lw;
 		tp->dy1 = -tp->dy1;
 	}
-	XSetLineAttributes(display, gc, tp->linewidth + (tp->shape >= 2),
+	XSetLineAttributes(display, tp->gc, tp->linewidth + (tp->shape >= 2),
 			   LineSolid, CapNotLast, JoinRound);
 	if (tp->shape < 2)
-		XDrawRectangle(display, window, gc,
+		XDrawRectangle(display, window, tp->gc,
 			       tp->x1, tp->y1, tp->width, tp->height);
 	else if (tp->shape == 2)
-		XDrawArc(display, window, gc,
+		XDrawArc(display, window, tp->gc,
 			 tp->x1, tp->y1, tp->width, tp->height, 0, 23040);
 	else {
 		for (i = 0; i <= (unsigned int) tp->shape; i++) {
 			tp->pts[i].x = tp->x1 + tp->proto_pts[i].x;
 			tp->pts[i].y = tp->y1 + tp->proto_pts[i].y;
 		}
-		XDrawLines(display, window, gc, tp->pts, tp->shape + 1,
+		XDrawLines(display, window, tp->gc, tp->pts, tp->shape + 1,
 			   CoordModeOrigin);
 	}
-	XSetLineAttributes(display, gc, 1, LineSolid, CapNotLast, JoinRound);
+	XSetLineAttributes(display, tp->gc, 1, LineSolid, CapNotLast, JoinRound);
 
-#ifndef STANDALONE
-	/* advance colormap */
-	if (!tp->fixed_colormap && tp->usable_colors > 2) {
-#if 1
-		for (i = 0, j = tp->cur_color;
-		     i < (unsigned int) tp->ncolors; i++) {
-#else
-		for (i = (unsigned int) tp->ncolors - 1, j = tp->cur_color;
-		     i >= 0; i--) {
-#endif
-			if (i == MI_WHITE_PIXEL(mi)) {
-				tp->colors[i].pixel = i;
-				tp->colors[i].red = 65535;
-				tp->colors[i].blue = 65535;
-				tp->colors[i].green = 65535;
-				tp->colors[i].flags = DoRed | DoGreen | DoBlue;
-			} else if (i == MI_BLACK_PIXEL(mi)) {
-				tp->colors[i].pixel = i;
-				tp->colors[i].red = 0;
-				tp->colors[i].blue = 0;
-				tp->colors[i].green = 0;
-				tp->colors[i].flags = DoRed | DoGreen | DoBlue;
-			} else if (i == MI_BG_PIXEL(mi)) {
-				tp->colors[i] = tp->bgcol;
-			} else if (i == MI_FG_PIXEL(mi)) {
-				tp->colors[i] = tp->fgcol;
-			} else {
-				double      range;
-
-				tp->colors[i].pixel = i;
-				range = ((double) (tp->top.red - tp->bottom.red)) /
-					tp->ncolors;
-				tp->colors[i].red = (short unsigned int) (range * j +
-							     tp->bottom.red);
-				range = ((double) (tp->top.green - tp->bottom.green)) /
-					tp->ncolors;
-				tp->colors[i].green = (short unsigned int) (range * j +
-							   tp->bottom.green);
-				range = ((double) (tp->top.blue - tp->bottom.blue)) /
-					tp->ncolors;
-				tp->colors[i].blue = (short unsigned int) (range * j +
-							    tp->bottom.blue);
-				tp->colors[i].flags = DoRed | DoGreen | DoBlue;
-				if (tp->reverse)
-					j = (j + 1) % tp->ncolors;
-				else
-					j = (j - 1 + tp->ncolors) % tp->ncolors;
-			}
-		}
-		/* make the entire tube move forward */
-		XStoreColors(display, tp->cmap, tp->colors, tp->ncolors);
-		setColormap(display, window, tp->cmap, MI_IS_INWINDOW(mi));
-	}
-#endif /* !STANDALONE */
 	tp->counter++;
 	if (tp->counter > MI_CYCLES(mi)) {
 		init_tube(mi);
