@@ -976,7 +976,7 @@ init_wire(ModeInfo * mi)
 void
 draw_wire(ModeInfo * mi)
 {
-	int         offset, i, j;
+	int         offset, i, j, found = 0;
 	unsigned char *z, *znew;
 	circuitstruct *wp;
 
@@ -995,6 +995,7 @@ draw_wire(ModeInfo * mi)
 			z = wp->oldcells + offset;
 			znew = wp->newcells + offset;
 			if (*z != *znew) {	/* Counting on once a space always a space */
+				found = 1;
 				*z = *znew;
 				if (!addtolist(mi, i - 2, j - 2, *znew - 1)) {
 					free_wire(MI_DISPLAY(mi), wp);
@@ -1008,7 +1009,7 @@ draw_wire(ModeInfo * mi)
 			free_wire(MI_DISPLAY(mi), wp);
 			return;
 		}
-	if (++wp->generation > MI_CYCLES(mi)) {
+	if (++wp->generation > MI_CYCLES(mi) || !found) {
 		init_wire(mi);
 		return;
 	} else
