@@ -405,6 +405,7 @@ static int  check_dce_net_passwd(char *, char *);
 #if defined( HAVE_KRB4 ) || defined( HAVE_KRB5 )
 #ifdef HAVE_KRB4
 #include <krb.h>
+static int krb_check_password(struct passwd *, char *);
 #else /* HAVE_KRB5 */
 #include <krb5.h>
 #include <com_err.h>
@@ -412,8 +413,8 @@ int krb5_valid = 0;
 extern Display *dsp;
 extern Window parent;
 extern Bool parentSet;
-#endif
 static int  krb_check_password(char *, char *);
+#endif
 
 #endif
 
@@ -1330,7 +1331,12 @@ checkPasswd(char *buffer)
 #if 0
 		if (!strcmp(userpass, "*"))
 #endif
+#ifdef HAVE_KRB4
+			if (krb_check_password((struct passwd *) getpwuid(getuid
+()), buffer2))
+#else
 			if (krb_check_password(user, buffer2))
+#endif
 				return True;
 	}
 #endif /* !HAVE_KRB4 && !HAVE_KRB5 */
@@ -1684,7 +1690,7 @@ check_dce_net_passwd(char *usr, char *pass)
 
 #ifdef HAVE_KRB4
 int
-krb_check_password(char *user, char *pass)
+krb_check_password(struct passwd *pwd, char *pass)
 {
 	char        realm[REALM_SZ];
 	char        tkfile[MAXPATHLEN];
