@@ -170,6 +170,7 @@ static int  descr();
 # define DEF_PASS	"Mot de passe: "
 # define DEF_VALID	"Validation ..."
 # define DEF_INVALID	"Mot de passe Invalide."
+# define DEF_INVALIDCAPSLOCK	"Mot de passe Invalide, Caps Lock on."
 # define DEF_INFO	"Entrez le mot de passe ou choisissez l'icone pour verrouiller."
 # define DEF_COUNT_FAILED	" essais chou."
 # define DEF_COUNTS_FAILED	" essais chous."
@@ -179,7 +180,11 @@ static int  descr();
 # define DEF_PASS	"Wachtwoord: "
 # define DEF_VALID	"Aan het checken ..."
 # define DEF_INVALID	"Ongeldig wachtwoord."
-# define DEF_INFO	"Geef wachtwoord om te ontgrendelen ; selecteer het icoon om te vergrendelen."
+# define DEF_INVALIDCAPSLOCK    "Ongeldig wachtwoord, Hoofdlettertoets ingedrukt."
+# define DEF_INFO       "Geef wachtwoord om te ontgrendelen ; selecteer het icoon om te vergrendelen."
+#ifdef HAVE_KRB5
+#define DEF_KRBINFO   "Geef Kerberos wachtwoord om te ontgrendelen ; selecteer het icoon om te vergrendelen."
+#endif /* HAVE_KRB5 */
 # define DEF_COUNT_FAILED	" mislukte poging."
 # define DEF_COUNTS_FAILED	" mislukte pogingen."
 #else
@@ -190,7 +195,11 @@ static int  descr();
 # define DEF_PASS	"Password: "
 # define DEF_VALID	"Validating login..."
 # define DEF_INVALID	"Invalid login."
+# define DEF_INVALIDCAPSLOCK	"Invalid login, Caps Lock on."
 # define DEF_INFO	"Enter password to unlock; select icon to lock."
+#ifdef HAVE_KRB5
+#define DEF_KRBINFO   "Enter Kerberos password to unlock; select icon to lock."
+#endif /* HAVE_KRB5 */
 # define DEF_COUNT_FAILED	" failed attempt."
 # define DEF_COUNTS_FAILED	" failed attempts."
 #endif
@@ -425,6 +434,7 @@ static XrmOptionDescRec genTable[] =
 	{(char *) "-info", (char *) ".info", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-validate", (char *) ".validate", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-invalid", (char *) ".invalid", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-invalidCapsLock", (char *) ".invalidCapsLock", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-geometry", (char *) ".geometry", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-icongeometry", (char *) ".icongeometry", XrmoptionSepArg, (caddr_t) NULL},
 #ifdef FX
@@ -646,6 +656,7 @@ static OptionStruct opDesc[] =
 	{(char *) "-info string", (char *) "text string to use for instructions"},
   {(char *) "-validate string", (char *) "text string to use for validating password message"},
       {(char *) "-invalid string", (char *) "text string to use for invalid password message"},
+      {(char *) "-invalidCapsLock string", (char *) "text string to use for invalid password message with Caps Lock on"},
 	{(char *) "-geometry geom", (char *) "geometry for non-full screen lock"},
    {(char *) "-icongeometry geom", (char *) "geometry for password window (location ignored)"},
 #ifdef FX
@@ -799,8 +810,12 @@ char       *text_chall;
 
 #endif
 char       *text_info;
+#ifdef HAVE_KRB5
+char	   *text_krbinfo;
+#endif /* HAVE_KRB5 */
 char       *text_valid;
 char       *text_invalid;
+char       *text_invalidCapsLock;
 char	   *failed_attempt;
 char	   *failed_attempts;
 char       *geometry;
@@ -916,8 +931,12 @@ static argtype genvars[] =
    {(caddr_t *) & text_chall, (char *) "challenge", (char *) "Challenge", (char *) DEF_CHALL, t_String},
 #endif
 	{(caddr_t *) & text_info, (char *) "info", (char *) "Info", (char *) DEF_INFO, t_String},
+#ifdef HAVE_KRB5
+	{(caddr_t *) & text_krbinfo, (char *) "kerberosinfo", (char *) "KerberosInfo", (char *) DEF_KRBINFO, t_String},
+#endif /* HAVE_KRB5 */
      {(caddr_t *) & text_valid, (char *) "validate", (char *) "Validate", (char *) DEF_VALID, t_String},
    {(caddr_t *) & text_invalid, (char *) "invalid", (char *) "Invalid", (char *) DEF_INVALID, t_String},
+   {(caddr_t *) & text_invalidCapsLock, (char *) "invalidCapsLock", (char *) "InvalidCapsLock", (char *) DEF_INVALIDCAPSLOCK, t_String},
    {(caddr_t *) & failed_attempt, (char *) "attempt", (char *) "Attempt", (char *) DEF_COUNT_FAILED, t_String},
    {(caddr_t *) & failed_attempts, (char *) "attempts", (char *) "Attempts", (char *) DEF_COUNTS_FAILED, t_String},
     {(caddr_t *) & geometry, (char *) "geometry", (char *) "Geometry", (char *) DEF_GEOMETRY, t_String},
@@ -1120,24 +1139,24 @@ checkSpecialArgs(int argc, char **argv)
 	int         i;
 
 	for (i = 0; i < argc; i++) {
-		if (!strncmp(argv[i], "-help", strlen(argv[i])))
+		if (!strcmp(argv[i], "-help"))
 			Help();
-		if (!strncmp(argv[i], "-version", strlen(argv[i])))
+		if (!strcmp(argv[i], "-version"))
 			Version();
 #ifdef CHECK_OLD_ARGS
 		{
 			static char *depreciated_args[] =
 	{(char *) "-v", (char *) "-imagefile", (char *) "-mfont",
-	 (char *) "-rule3d", (char *) "-life3dfile", (char *) "-mouse",
-	 (char *) "-shift", (char *) "-tshift"};
+	 (char *) "-rule3d", (char *) "-life3dfile",
+	 (char *) "-mouse", (char *) "-shift", (char *) "-tshift"};
 			static char *current_args[] =
 	{(char *) "-verbose", (char *) "-bitmap", (char *) "-messagefont",
-	 (char *) "-rule", (char *) "-lifefile", (char *) "-trackmouse",
-	 (char *) "-cycle", (char *) "-cycle"};
+	 (char *) "-rule", (char *) "-lifefile",
+	 (char *) "-trackmouse", (char *) "-cycle", (char *) "-cycle"};
 			int         j;
 
 			for (j = 0; j < (int) ((sizeof current_args) / sizeof (*current_args)); j++)
-				if (!strncmp(argv[i], depreciated_args[j], strlen(argv[i]))) {
+				if (!strcmp(argv[i], depreciated_args[j])) {
 					(void) printf("%s depreciated, use %s\n",
 					depreciated_args[j], current_args[j]);
 					exit(0);
