@@ -202,7 +202,7 @@ FreeAllGL(ModeInfo * mi)
   			clear_gl_error ();
 			if (glIsList(font_dlist)) {
 	  			glDeleteLists (font_dlist,(GLuint) last+1);
-  				check_gl_error ("glDeleteLists");
+  				(void) check_gl_error ("glDeleteLists");
 				font_dlist = 0;
 			}
 			XFreeFont(MI_DISPLAY(mi),font_struct);
@@ -221,14 +221,14 @@ clear_gl_error (void)
 }
 
 /* report a GL error. */
-void
+Bool
 check_gl_error (const char *type)
 {
   char buf[100];
   GLenum i;
   const char *e;
   switch ((i = glGetError())) {
-  case GL_NO_ERROR: return;
+  case GL_NO_ERROR: return False;
   case GL_INVALID_ENUM:          e = "invalid enum";      break;
   case GL_INVALID_VALUE:         e = "invalid value";     break;
   case GL_INVALID_OPERATION:     e = "invalid operation"; break;
@@ -245,7 +245,7 @@ check_gl_error (const char *type)
     e = buf; (void) sprintf (buf, "unknown error %d", (int) i); break;
   }
   (void) fprintf (stderr, "XLock: %s error: %s\n", type, e);
-  exit (1);
+  return True;
 }
 
 
@@ -255,7 +255,7 @@ static int fps_text_x = 10;
 static int fps_text_y = 10;
 static int fps_sample_frames = 10;
 
-static void
+static Bool
 fps_init (ModeInfo *mi)
 {
   const char *font = fpsfontname;
@@ -274,30 +274,37 @@ fps_init (ModeInfo *mi)
   
   clear_gl_error ();
   font_dlist = glGenLists ((GLuint) last+1);
-  check_gl_error ("glGenLists");
+  if (check_gl_error ("glGenLists"))
+ 	return False;
 
   if (fpsTop) /* Draw string on top of screen */
     fps_text_y = - (f->ascent + 10);
 
   glXUseXFont(id, first, last-first+1, font_dlist + first);
-  check_gl_error ("glXUseXFont");
+  return (!check_gl_error ("glXUseXFont"));
 }
 
-static void
+static Bool
 fps_print_string (ModeInfo *mi, GLfloat x, GLfloat y, const char *string)
 {
+  static GLfloat red = 0.0, green = 0.0, blue = 0.0;
   int i;
   /* save the current state */
   /* note: could be expensive! */
 
+  while (red == 0.0 && green == 0.0 && blue == 0.0) { 
+     red = NRAND(2) ? 1.0 : 0.0;
+     green = NRAND(2) ? 1.0 : 0.0;
+     blue = NRAND(2) ? 1.0 : 0.0;
+  }
   if (y < 0)
     y = MI_HEIGHT(mi) + y;
 
   clear_gl_error ();
   glPushAttrib(GL_ALL_ATTRIB_BITS);
   {
-    check_gl_error ("glPushAttrib");
-
+    if (check_gl_error ("glPushAttrib"))
+	return False;
     /* disable lighting and texturing when drawing bitmaps!
        (glPopAttrib() restores these, I believe.)
      */
@@ -311,7 +318,8 @@ fps_print_string (ModeInfo *mi, GLfloat x, GLfloat y, const char *string)
     glMatrixMode(GL_PROJECTION);
     glPushMatrix();
     {
-      check_gl_error ("glPushMatrix");
+      if (check_gl_error ("glPushMatrix"))
+	return False;
       glLoadIdentity();
 
       /* Each matrix mode has its own stack, so we need to push/pop
@@ -319,19 +327,21 @@ fps_print_string (ModeInfo *mi, GLfloat x, GLfloat y, const char *string)
       glMatrixMode(GL_MODELVIEW);
       glPushMatrix();
       {
-        check_gl_error ("glPushMatrix");
+        if (check_gl_error ("glPushMatrix"))
+	  return False;
         glLoadIdentity();
 
         gluOrtho2D(0.0, (GLfloat) MI_WIDTH(mi), 0.0, (GLfloat) MI_HEIGHT(mi));
-        check_gl_error ("gluOrtho2D");
-
+        if (check_gl_error ("gluOrtho2D"))
+	  return False;
         /* draw the text */
-        glColor3f (1.0, 0.0, 0.0);
+        glColor3f (red, green, blue);
         glRasterPos2f (x, y);
         for (i = 0; i < (int) strlen(string); i++)
           glCallList (font_dlist + (int)string[i]);
 
-        check_gl_error ("fps_print_string");
+        if (check_gl_error ("fps_print_string"))
+	  return False;
       }
       glPopMatrix();
     }
@@ -341,7 +351,7 @@ fps_print_string (ModeInfo *mi, GLfloat x, GLfloat y, const char *string)
   }
   /* clean up after our state changes */
   glPopAttrib();
-  check_gl_error ("glPopAttrib");
+  return (!check_gl_error ("glPopAttrib"));
 }
 
 
@@ -358,12 +368,12 @@ do_fps (ModeInfo *mi)
   if (MI_IS_ICONIC(mi))
   {
 	/* don't do it in iconic state */
-	frame_counter = fps_sample_frames;
 	return;
   }
   if (frame_counter == -1)
     {
-      fps_init (mi);
+      if (!fps_init (mi))
+	return;
       frame_counter = fps_sample_frames;
     }
 
@@ -410,7 +420,6 @@ do_fps (ModeInfo *mi)
 
       frame_counter = 0;
     }
-
-  fps_print_string (mi, (float) fps_text_x, (float) fps_text_y, msg);
+    (void) fps_print_string (mi, (float) fps_text_x, (float) -fps_text_y, msg);
 }
 #endif
